@@ -11,8 +11,7 @@ from arkitekt.qt.widgets.provisions import ProvisionsWidget
 from arkitekt.qt.widgets.templates import TemplatesWidget
 from herre.qt import QtHerre
 from fakts.qt import QtFakts
-from fakts.grants.qtyamlgrant import QtYamlGrant
-from fakts.grants.qtbeacon import QtSelectableBeaconGrant
+from fakts.grants.qt.qtbeacon import QtSelectableBeaconGrant
 
 
 class NapariSettings(SettingsPopup):
@@ -35,9 +34,8 @@ class ArkitektWidget(QtWidgets.QWidget):
 
         # Different Grants
 
-        self.file_grant = QtYamlGrant("querk.yaml")
         self.beacon_grant = QtSelectableBeaconGrant()
-        self.fakts = QtFakts(grants=[self.file_grant, self.beacon_grant], save_conf="querk.yaml")
+        self.fakts = QtFakts(grants=[self.beacon_grant], hard_fakts={"herre": {"client_id": "go8CAE78FDf4eLsOSk4wkR4usYbsamcq0yTYqBiY"}})
         self.herre = QtHerre()
         self.agent = QtAgent(self)
 
@@ -46,8 +44,8 @@ class ArkitektWidget(QtWidgets.QWidget):
 
         self.magic_bar = NapariMagicBar(self.fakts, self.herre, self.agent, parent=self, darkMode=True)
 
-        self.agent.register(self.really_show, widgets={"rep": MY_TOP_REPRESENTATIONS}, on_assign=self.really_show)
-        self.agent.register(self.upload, widgets={"sample": MY_TOP_SAMPLES}, on_assign=self.upload)
+        self.agent.register_ui(self.really_show, widgets={"rep": MY_TOP_REPRESENTATIONS}, on_assign=self.really_show)
+        self.agent.register_ui(self.upload, widgets={"sample": MY_TOP_SAMPLES}, on_assign=self.upload)
 
 
         self.layout = QtWidgets.QVBoxLayout()
